<?php
session_start();
require_once 'config.php';

if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// التحقق من صلاحية الاشتراك
$stmt = $pdo->prepare("SELECT subscription_end FROM users WHERE id = ?");
$stmt->execute([$_SESSION['user_id']]);
$user = $stmt->fetch();

if (strtotime($user['subscription_end']) < time()) {
    session_destroy();
    header('Location: login.php');
    exit();
}
?>

<!DOCTYPE html>
<html dir="rtl">
<head>
    <title>لوحة التحكم</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
        }
        .dashboard {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 20px;
        }
        .card {
            background: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        .product-list {
            margin-top: 20px;
        }
        .cart {
            position: fixed;
            right: 20px;
            top: 20px;
            background: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
    </style>
</head>
<body>
    <div class="dashboard">
        <div class="card">
            <h2>المبيعات</h2>
            <div id="sales-section">
                <!-- قائمة المنتجات -->
            </div>
        </div>
        
        <div class="card">
            <h2>الرسائل التلقائية</h2>
            <form id="message-form">
                <textarea name="message" placeholder="نص الرسالة"></textarea>
                <input type="text" name="phones" placeholder="أرقام الهواتف (مفصولة بفواصل)">
                <input type="datetime-local" name="schedule_time">
                <button type="submit">جدولة الرسالة</button>
            </form>
        </div>
    </div>

    <div class="cart">
        <h3>السلة</h3>
        <div id="cart-items"></div>
        <div id="cart-total">المجموع: 0</div>
        <button onclick="checkout()">إتمام البيع</button>
    </div>

    <script>
        // دالة تحميل المنتجات
        function loadProducts() {
            fetch('get_products.php')
                .then(response => response.json())
                .then(products => {
                    const productsHTML = products.map(product => `
                        <div class="product">
                            <span>${product.name}</span>
                            <span>${product.price}</span>
                            <button onclick="addToCart(${product.id})">إضافة</button>
                        </div>
                    `).join('');
                    document.getElementById('sales-section').innerHTML = productsHTML;
                });
        }

        // دالة إضافة منتج للسلة
        function addToCart(productId) {
            // إضافة المنتج للسلة
        }

        // دالة إتمام البيع
        function checkout() {
            // إتمام عملية البيع
        }

        // دالة إرسال الرسائل
        document.getElementById('message-form').onsubmit = function(e) {
            e.preventDefault();
            const formData = new FormData(this);
            fetch('schedule_message.php', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('تم جدولة الرسالة بنجاح');
                }
            });
        };

        // تحميل المنتجات عند فتح الصفحة
        loadProducts();
    </script>
</body>
</html>